@@ -16,7 +16,7 @@ import os
 from enum import Enum
 from numbers import Number
 from dataclasses import dataclass, fields, asdict
-from typing import List, Union, Sequence
+from typing import List, Union, Sequence, TypeVar
 
 from agml.framework import AgMLSerializable
 from agml.synthetic.config import load_default_helios_configuration, verify_helios
@@ -37,6 +37,9 @@ class SimulationType(Enum):
     LiDAR: str = "lidar"
 
 
+NumberOrMaybeList = TypeVar('NumberOrMaybeList', Number, List[Number])
+
+
 @dataclass(repr = False)
 class Parameters:
     """Base class for parameters, to enable runtime type checks."""
@@ -75,8 +78,8 @@ class Parameters:
             annotation = (int, float)
         if not isinstance(value, annotation):
             raise TypeError(
-                f"Expected a value of type ({annotation}) for attribute "
-                f"'{key}', instead got '{value}' of type ({type(value)}).")
+               f"Expected a value of type ({annotation}) for attribute "
+               f"'{key}', instead got '{value}' of type ({type(value)}).")
         super().__setattr__(key, value)
 
 
@@ -141,9 +144,9 @@ class CanopyParameters(Parameters):
     shoot_angle_tip: Number               = None
     shoot_angle_base: Number              = None
     shoot_color: List[Number]             = None
-    shoot_subdivisions: List[Number]      = None
+    shoot_subdivisions: NumberOrMaybeList = None
     pod_color: List[Number]               = None
-    pod_subdivisions: List[Number]        = None
+    pod_subdivisions: NumberOrMaybeList   = None
     pod_length: None                      = None
     germination_probability: Number       = None
     needle_width: Number                  = None
@@ -227,14 +230,15 @@ class CameraParameters(Parameters):
                            num_views: int,
                            origin: List[Union[int, float]] = None,
                            camera_spacing: int = 2,
-                           crop_distance: int = 4,
-                           height: int = 1):
+                           crop_distance: Union[int, float] = 4,
+                           height: int = 1,
+                           aerial_parameters: dict = {}):
         """Generates camera positions from the input environment parameters."""
         self.camera_position, self.camera_lookat = generate_camera_positions(
             camera_type = camera_type, num_views = num_views,
             origin = origin, camera_spacing = camera_spacing,
-            crop_distance = crop_distance, height = height)
-
+            crop_distance = crop_distance, height = height,
+            aerial_parameters = aerial_parameters)
 
 @dataclass(repr = False)
 class LiDARParameters(Parameters):
