@@ -15,7 +15,8 @@
 from .tools import (
     format_image,
     set_colormap,
-    get_colormap
+    get_colormap,
+    convert_figure_to_image
 )
 from .masks import (
     output_to_mask,
@@ -31,9 +32,12 @@ from .boxes import (
     visualize_image_and_many_boxes
 )
 from .labels import (
-    visualize_images,
     visualize_images_with_labels
 )
+from .general import (
+    visualize_images,
+    show_sample
+)
 from .inspection import (
     plot_synthetic_camera_positions,
     visualize_all_views
