@@ -17,6 +17,7 @@ A tools module for `agml.viz`, which also serves as almost a
 mini-backend to control ops such as the colormap being used.
 """
 import os
+import io
 import json
 import functools
 
@@ -62,16 +63,27 @@ def set_colormap(colormap):
     1. "default": Traditional matplotlib RGB colors.
     2. "agriculture": Various shades of green (for agriculture).
 
+    If you want to set a custom colormap, then pass a list of RGB
+    values which will be used as the colormap.
+
     Parameters
     ----------
     colormap : str
         The colormap to set.
     """
     global _COLORMAP_CHOICE, _COLORMAPS
-    colormap = colormap.lower()
-    if colormap not in _COLORMAPS.keys():
-        raise ValueError(f"Invalid colormap {colormap} received.")
-    _COLORMAP_CHOICE = colormap
+    if isinstance(colormap, list):
+        if not all(len(i) == 3 for i in colormap):
+            raise ValueError(
+                "If you want a custom colormap, then pass a list of RGB values.")
+    elif isinstance(colormap, str):
+        colormap = colormap.lower()
+        if colormap not in _COLORMAPS.keys():
+            raise ValueError(f"Invalid colormap {colormap} received.")
+    else:
+        raise TypeError(f"Invalid colormap of type {type(colormap)}.")
+    _COLORMAPS['custom'] = colormap
+    _COLORMAP_CHOICE = 'custom'
 
 
 def auto_resolve_image(f):
@@ -192,3 +204,30 @@ def format_image(img, mask = False):
 
     # Return the formatted image.
     return img
+
+
+def convert_figure_to_image(fig = None):
+    """This method is used to convert a Matplotlib figure to an image array."""
+    # Use PIL to get the image, then convert to an array.
+    buf = io.BytesIO()
+    fig = fig if fig is not None else plt.gcf()
+    fig.savefig(buf, format = 'png')
+    buf.seek(0)
+    arr = np.fromstring(buf.read(), dtype = np.uint8)
+    return cv2.imdecode(arr, cv2.IMREAD_COLOR)
+
+
+def _inference_best_shape(n_images):
+    """Inferences the best matplotlib row/column layout.
+
+    This method searches for the two closest factors of the number
+    `n_images`, and returns this tuple as the best shape, since this
+    is the closest to a square grid as possible.
+    """
+    a, b, i = 1, n_images, 0
+    while a < b:
+        i += 1
+        if n_images % i == 0:
+            a = i
+            b = n_images // a
+    return [b, a]
